Statistics
==========

.. currentmodule:: numpy


Order statistics
----------------

.. autosummary::
   :toctree: generated/

   amin
   amax
   nanmin
   nanmax
   ptp
   percentile

Averages and variances
----------------------

.. autosummary::
   :toctree: generated/

   median
   average
   mean
   std
   var
   nanmean
   nanstd
   nanvar

Correlating
-----------

.. autosummary::
   :toctree: generated/

   corrcoef
   correlate
   cov

Histograms
----------

.. autosummary::
   :toctree: generated/

   histogram
   histogram2d
   histogramdd
   bincount
   digitize
